//
//  ImageLoader.h
//  Memories
//
//  Created by Benny Sheerin on 5/02/12.
//  Copyright (c) 2012 bennythemink. All rights reserved.
//  www.bennythemink.com
//

#import <Foundation/Foundation.h>
#import "/usr/include/sqlite3.h"

@protocol ImageLoaderDelegate <NSObject>

@required

- (void) didLoadImage:(UIImage*)image forUrlString:(NSString*)urlString;
- (void) didFailLoadImageForUrlString:(NSString*)urlString withMessage:(NSString*)message;

@end

@interface ImageLoader : NSObject <NSURLConnectionDelegate> {
    sqlite3 *imageDatabase;
}

@property (strong, nonatomic) NSMutableArray *downloadQueue;
@property (strong, nonatomic) NSMutableDictionary *delegates;
@property (strong, nonatomic) NSDictionary *currentImageBeingDownloaded;

@property (weak, nonatomic) id <ImageLoaderDelegate> imageLoaderDelegate;
@property (strong, nonatomic) NSURLConnection *connection;
@property (strong, nonatomic) NSMutableData *responseData;
@property (strong, nonatomic) NSString *currentUrlString;
@property (nonatomic) NSInteger daysToCache;
@property (nonatomic) BOOL isCurrentlyProcessing;
@property (strong, nonatomic) NSString *databasePath;

#pragma mark - Methods

+ (ImageLoader*) sharedImageLoader;

- (void) loadImageWithUrlString:(NSString*)urlString withDelegate:(id)delegate daysToCache:(NSInteger)days;
- (void) processNextDownload;

- (BOOL) checkAndCreateDatabaseIfNeeded;
- (void) createAndStartConnection;
- (int) daysToSeconds:(int)days;
- (NSDictionary*) readRowForUrlString:(NSString*)urlString;
- (NSString*) cacheImage:(UIImage*)image;
- (BOOL) saveEntryInDatabaseForUrlString:(NSString*)urlString andPathToFile:(NSString*)pathToFile;

@end
